#!/bin/sh

# -- Generate an O Europae MIDI file in the Peppermint 24 temperament --
# This file will use MIDI pitchbend messages.

microabc -MO_Europae.abp -ipep24-key1.txt procsag:0 > O_Europaemidi.abc
abc2midi O_Europaemidi.abc
# We recommend timidity with -R8 --reverb=d option
# for these and other MIDI files with pitch bends. 
# Optionally one could do 
# timidity -R8 --reverb=d reverb=g,50 OEuropaemidi1.mid
# for a global reverb effect (in a range of 0-127, here 50)

# -- Generate PostScript and PDF score files using sagittal.pfb font --
# Here we use an .abp file with the '%%format sagittal-pfb.format'
# option. The file name O_Europaepfb.abp warns that we are
# going to produce a PostScript file with a font dependency.
# Note that if the format file is not in the current directory,
# we must also specify its path, thus if we are generating from 
# a first-level subdirectory of the microabc directory where 
# this file is kept, '%%format ../sagittal-pfb.format'

# NOTE: abcm2ps will as a default search for format files in the
# current directory and also the "default format directory" which
# can be displayed with the command 'abcm2ps -V'; in GNU/Linux, this 
# directory is /usr/local/share/abcm2ps -- while microabc-2006-07-10 
# does not copy the .fmt files to this directory during the 
# installation process, a user might do so, and future versions might
# automate the process with a makefile.    

# CAUTION: The PostScript file requires that our Type 1 font
# be present in PostScript virtual memory when the file is run, 
# but the PDF file includes it, neatly avoiding this complication.
# Thus when using this option, PDF distribution is best.
microabc -PO_Europaepfb.abp -S -i- > O_Europaepfb.abc
abcm2ps O_Europaepfb.abc -O O_Europaepfb.ps 

# File can now be viewed or printed provided PostScript
# printer or software interpreter (e.g. Ghostscript) has
# access to sagittal.pfb font; as a warning, a file name
# with *pfb.abp, *pfb.abc, or *pfb.ps warns of this
# font dependency. Now we generate a self-sufficent PDF.
# The 'ps2pdf12' option seeks better backward compatibility.
ps2pdf12 O_Europaepfb.ps O_Europae.pdf

# In addition to being freely portable while using the 
# higher-quality PostScript Type 1 font, the PDF file
# may be more compact than PostScript, another advantage.   

# -- Generate self-sufficient PostScript score --
# This will include the font information, but will not
# have the hinting information of the Type 1 format, and
# will be considerably larger than a PostScript file
# relying on sagittal.pfb or a self-sufficient PDF file.
# We use O_Europae.abp, with '%%format sagittal.fmt'
# option again specifying a path if the format file is
# in another directory, e.g. '%%format ../sagittal.fmt.' 
# Note that output file from microabc is named
# O_Europaeps.abc to tell us that it is for use with 
# abc2mps in generating a score, rather for MIDI files.

microabc -PO_Europae.abp -S -i- > O_Europaeps.abc
abcm2ps O_Europaeps.abc -O O_Europae.ps
# Self-sufficient PostScript file should run on any
# PostScript printer or software interpreter supporting
# Level 2.

# We can also generate a PDF file from this PostScript 
# file which uses a Type 3 font.

ps2pdf12 O_Europae.ps O_EuropaeType3.pdf 

# -- Generate MIDI files in sagittal just intonation --

# We can also produce files using a just intonation 
# interpretation of the sagittal symbols, albeit with
# sometimes unpredictable results given that the music 
# was intended for the Peppermint 24 tuning system. 
# As it happens, here the results should generally be 
# rather similar, since the regular Peppermint 24 
# intervals are not too far from the Pythagorean tuning
# produced by the usual Sagittal notes and accidentals,
# while the Sagittal notation of the final cadence in
# this example specifies pure septimal intervals in a
# JI reading, with Peppermint either producing or
# closely approximating these same intervals (e.g. the
# pure 12:7 major sixth around 933 cents in either
# a Peppermint or JI reading).

# Note that this JI rendition is simpler for microabc 
# to handle, and requires only one step of processing 
# rather than the two for the Peppermint tuning to 
# produce an abc file for abc2midi. The 'procsag:1'
# option for microabc directs that Sagittal pitch 
# conversions should take place, the correct choice 
# for this JI reading. Although 'procsag:1' is not 
# strictly required with microabc-2006-07-10, it 
# is required for later versions where 'procsag:0' 
# ("do not do conversion of Sagittal pitches") is
# the default. 

microabc -i- -MO_Europae.abp procsag:1 > O_Europaemidipure.abc
abc2midi O_Europaemidipure.abc
